function normalizeCountryName(s) {
  return s.replaceAll(' ', '_').toLowerCase();
}

function parseNumStr(s) {
  return +s.replaceAll(',', '').replaceAll('$$', '');
}

export function parseMapData(mapData) {
  mapData.features.forEach((f) => {
    f.properties.name = normalizeCountryName(
      f.properties.name,
    );
  });
  return mapData;
}

export function parseCountryData(csvData, continentData) {
  var countryData = new Map();
  var countryToMapNames = new Map([
    ['United States', 'USA'],
    ['Tanzania', 'United Republic of Tanzania'],
    ['United Kingdom', 'England'],
    ['United Kingdom', 'Wales'],
    ['Republic of Ireland', 'Ireland'],
  ]);
  csvData.forEach((row) => {
    if (countryToMapNames.has(row.Country)) {
      row.Country = countryToMapNames.get(row.Country);
    }
    // Cleaning specific columns of my data
    // Each row is an object with attributes corresponding to the columns,
    // so I am going to overwrite the values for some of the attributes
    // to be the correct type/format
    row.Country_orig = row.Country;
    row.Country = normalizeCountryName(row.Country);
    row.Population_orig = row.Population;
    row.Population = parseNumStr(row.Population);
    row.Urban_population = parseNumStr(
      row.Urban_population,
    );
    row.Urban_rate = row.Urban_population / row.Population;
    row.GDP_per_capita =
      parseNumStr(row.GDP) / row.Population;
    // Since I'm going to be pulling in an extra dataset with Continent data,
    // I'll initialize a default "unknown" value that I will (hopefully!)
    // overwrite with the actual continent name. This is useful since now if
    // I'm missing data for any country, it will have a valid attribute when I
    // select the .Continent, saving me from anoying "undefined" bugs
    row.Continent = 'Unknown';
    countryData.set(row.Country, row);
  });

  continentData.forEach((row) => {
    let name = normalizeCountryName(row.country);
    if (countryData.has(name)) {
      countryData.get(name).Continent =
        normalizeCountryName(row.continent);
    }
  });

  return countryData;
}
